CMAKE_CURRENT_FUNCTION
----------------------

.. versionadded:: 3.17

When executing code inside a :command:`function`, this variable
contains the name of the current function.  It can be useful for
diagnostic or debug messages.

See also :variable:`CMAKE_CURRENT_FUNCTION_LIST_DIR`,
:variable:`CMAKE_CURRENT_FUNCTION_LIST_FILE` and
:variable:`CMAKE_CURRENT_FUNCTION_LIST_LINE`.
